OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календар",
    "%s has published the calendar »%s«" : "%s је објавио календар »%s«",
    "Hello," : "Здраво, ",
    "We wanted to inform you that %s has published the calendar »%s«." : "Желимо да Вас обавестимо да је %s објавио календар »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Здраво!",
    "Recipient" : "Прималац",
    "Too many redirects. Aborting ..." : "Превише преусмеравања. Прекидам ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Удаљени сервер није дао приступ календару (HTTP грешка {%s})",
    "Error connecting to remote server" : "Грешка приликом повезивања са удаљеним сервером",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Грешка при захтевању ресурса са удаљеног сервера. Ово може бити изазвано неслагањем сертификата.",
    "Error requesting resource on remote server" : "Грешка приликом захтевања ресурса са удаљеног сервера",
    "Individual" : "Индивидуално",
    "Group" : "Група",
    "Resource" : "Ресурс",
    "Room" : "Соба",
    "Unknown" : "Непознато",
    "Required" : "Обавезно",
    "Optional" : "Необавезно",
    "Does not attend" : "Не присуствује",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "У непознатој сте временској зони ({tz}), пребачени сте на UTC универзално време",
    "Please create a calendar first." : "Молимо прво направите календар.",
    "New event" : "Нови догађај",
    "CalDAV address for clients" : "CalDAV адреса за клијенте",
    "Error saving WebCal-calendar" : "Грешка при чувању WebCal календара",
    "WebDAV address for subscriptions" : "WebDAV адреса за претплату",
    "Email has been sent." : "Е-пошта је послата.",
    "There was an issue while sending your email." : "Догодила се грешка приликом слања е-поште.",
    "group" : "група",
    "Details" : "Детаљи",
    "Attendees" : "Присутни",
    "Reminders" : "Подсетници",
    "Repeating" : "Понављање",
    "When shared show full event" : "Прикажи цео догађај када је догађај дељен",
    "When shared show only busy" : "Прикажи само да сте заузета када је догађај дељен",
    "When shared hide this event" : "Сакриј догађај када је догађај дељен",
    "Confirmed" : "Потврђен",
    "Tentative" : "Условна потврда",
    "Cancelled" : "Отказан",
    "Please add a title." : "Молимо унесите наслов.",
    "Please select a calendar." : "Молимо одаберите календар.",
    "The event can not end before it starts." : "Догађај се завршава пре него што је почео.",
    "Global" : "Опште",
    "None" : "Ништа",
    "Every day" : "Сваки дан",
    "Every week" : "Сваке седмице",
    "Every month" : "Сваки месец",
    "Every year" : "Сваке године",
    "never" : "никада",
    "after" : "након",
    "How about getting started by importing some calendars?" : "Како би било да почнете тако што увезете неке календаре?",
    "At time of event" : "Тачно на време догађаја",
    "5 minutes before" : "5 минута раније",
    "10 minutes before" : "10 минута раније",
    "15 minutes before" : "15 минута раније",
    "30 minutes before" : "30 минута раније",
    "1 hour before" : "1 сат раније",
    "2 hours before" : "2 сата раније",
    "Custom" : "Прилагођено",
    "Audio" : "Звук",
    "Email" : "Е-пошта",
    "Pop-up" : "Искочи",
    "sec" : "сек",
    "min" : "мин",
    "hours" : "сати",
    "days" : "дана",
    "week" : "седмица",
    "before" : "пре",
    "start" : "почетак",
    "end" : "завршетак",
    "Editing reminders of unknown type not supported." : "Измена подсетника непознатог типа није подржана.",
    "Week {number} of {year}" : "Недеља {number} у {year}",
    "{type} {time} before the event starts" : "{type} {time} пре него догађај почне",
    "{type} {time} before the event ends" : "{type} {time} пре него се догађај заврши",
    "{type} {time} after the event starts" : "{type} {time} пошто догађај почне",
    "{type} {time} after the event ends" : "{type} {time} пошто се догађај заврши",
    "{type} at the event's start" : "{type} када догађај почне",
    "{type} at the event's end" : "{type} када се догађај заврши",
    "{type} at {time}" : "{type} у {time}",
    "{calendar} shared by {owner}" : "{calendar} је подељен од стране {owner}",
    "Please enter a valid WebCal-URL" : "Унесите исправну WebCal адресу",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Фатална грешка у webcal проксију. Контактирајте администратора за више информација.",
    "Title of the Event" : "Наслов догађаја",
    "Starts" : "Почиње",
    "Ends" : "Завршава",
    "All day Event" : "Целодневни догађај",
    "Delete" : "Обриши",
    "Cancel" : "Одустани",
    "More ..." : "Још ...",
    "Create" : "Направи",
    "Update" : "Ажурирај",
    "Close" : "Затвори",
    "Location" : "Локација",
    "Description" : "Опис",
    "Event status" : "Статус догађаја",
    "Visibility when sharing" : "Видљивост приликом дељења",
    "Export" : "Извези",
    "%s has published the calendar %s" : "%s је објавио календар %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Желимо да Вас обавестимо да је %s објавио календар {boldstart}%s{boldend}.",
    "Click here to access it" : "Кликните овде да му приступите",
    "We wanted to inform you that %s has published the calendar %s." : "Желимо да Вас обавестимо да је %s објавио календар %s.",
    "Click on the link below to access it" : "Кликните на везу испод да му приступите",
    "Day" : "Дан",
    "Week" : "Недеља",
    "Month" : "Месец",
    "Today" : "Данас",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Неки догађаји у календару су оштећени. За више информација, проверите JS конзолу",
    "Share Calendar" : "Подели календар",
    "Shared" : "Дељено",
    "More" : "Остало",
    "Edit" : "Измени",
    "Link" : "Веза",
    "iCal link" : "iCal веза",
    "Download" : "Преузми",
    "Share with users or groups" : "Дели са корисницима или групама",
    "can edit" : "може да мења",
    "Share link" : "Дели везу",
    "Public access" : "Јавни приступ",
    "Email link to person" : "Пошаљи другој особи везу е-поштом",
    "Send" : "Пошаљи",
    "New Calendar" : "Нови календар",
    "Name" : "Назив",
    "New Subscription" : "Нова претплата",
    "Go back" : "Иди назад",
    "Go forward" : "Иди напред",
    "Calendar does not exist" : "Календар не постоји",
    "Maybe you got a wrong link or the calendar was unshared?" : "Можда сте добили лошу везу или календар више није дељен?",
    "Edit event" : "Измени догађај",
    "Delete Event" : "Обриши догађај",
    "Save Event" : "Сачувај догађај",
    "Time" : "време",
    "Type" : "Тип",
    "Relative" : "Релативно",
    "Absolute" : "Апсолутно",
    "Repeat" : "Понављај",
    "times every" : "пута сваких",
    "Add" : "Додај",
    "Email address of attendee" : "Адреса е-поште учесника",
    "Please add your email address in the personal settings in order to add attendees." : "Додајте адресу Ваше е-поште у личним подешавањима да бисте додали учеснике",
    "from" : "од",
    "to" : "за",
    "This event's repeating rule is not supported yet." : "Правило понављања овог догађаја није још подржано.",
    "Support for advanced rules will be added with subsequent updates." : "Подршка за напреднија правила ће бити додата у будућим ажурирањима.",
    "Reset repeating rule" : "Ресетуј правило понављања",
    "Repeat every ..." : "Понављај сваких ...",
    "end repeat ..." : "заврши понављање ...",
    "times" : "пута",
    "Import Calendars" : "Увези календаре",
    "Import canceled" : "Увоз отказан",
    "Analyzing calendar" : "Анализирам календар",
    "The file contains objects incompatible with the selected calendar" : "Фајл садржи објекте који нису компатибилни са означеним календаром",
    "New calendar" : "Нови календар",
    "File is empty" : "Фајл је празан",
    "Import scheduled" : "Увези заказане",
    "%s shared the calendar <strong>%s</strong> with you" : "%s је поделио календар <strong>%s</strong> са Вама",
    "Embed" : "Угради",
    "Iframe to integrate" : "Iframe за интеграцију",
    "Publish URL" : "Објави URL",
    "Settings & import" : "Поставке & увоз",
    "Skip simple event editor" : "Прескочи једноставни уређивач догађаја",
    "Show week numbers" : "Прикажи број седмице",
    "Import calendar" : "Увези календар",
    "No Calendars selected for import" : "Није одабран ниједан календар за увоз",
    "Primary CalDAV address" : "Примарна CalDAV адреса",
    "iOS/OS X CalDAV address" : "иОС/ОС Икс CalDAV адреса",
    "Subscribe" : "Претплати се"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
